.. _kmeans:


Kmeans
======

The :meth:`kmeans()` function performs a segmentation on a :class:`DataCube` using KMeans clustering.

Example
-------

This examples shows the clustering of a synthetic generated :class:`DataCube`.

.. literalinclude:: ../../../../examples/02_process/00_kmeans.py
   :language: python
   :linenos:


.. figure:: ../../../../resources/imgs/examples/kmeans.png
   :align: center
   :alt: Cluster DataCube with kmeans().

   The output demonstrates an example segmentation with Kmeans.


